pub struct UserbootProxy { /* private fields */ }Implementations
Sourceimpl UserbootProxy
impl UserbootProxy
Sourcepub fn take_event_stream(&self) -> UserbootEventStream
pub fn take_event_stream(&self) -> UserbootEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn post_bootfs_files(&self, files: Vec<BootfsFileVmo>) -> Result<(), Error>
pub fn post_bootfs_files(&self, files: Vec<BootfsFileVmo>) -> Result<(), Error>
Posts a set of BootfsFileVmo that were used for launching the userboot.next= program and are no longer
available in the big BootfsVmo.
Messages will only become available after the Userboot protocol client end (userboot’s handle)
has been closed.
Sourcepub fn post_stash_svc(
&self,
stash_svc_endpoint: ServerEnd<SvcStashMarker>,
) -> Result<(), Error>
pub fn post_stash_svc( &self, stash_svc_endpoint: ServerEnd<SvcStashMarker>, ) -> Result<(), Error>
Posts svc_stash server endpoint. For more information refer to fuchsia.boot.SvcStash.